appsource

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 27, 2022 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AppSource

type AppSource interface {
	Path() string   // get the path to the folder containing R app scripts
	Cleanup() error // cleanup if any when app is deleted
	Error() error   // get the error status if any
}

A generic application source interface

func NewAppSource

func NewAppSource(app models.App, conf config.Config, checkOnly bool) AppSource

type AppSourceDir

type AppSourceDir struct {
	AppDir string
	// contains filtered or unexported fields
}

A simple app source based on a local folder

func NewAppSourceDir

func NewAppSourceDir(app models.App, conf config.Config) *AppSourceDir

func NewAppSourceSampleApp

func NewAppSourceSampleApp(app models.App, conf config.Config) *AppSourceDir

func (*AppSourceDir) Cleanup

func (s *AppSourceDir) Cleanup() error

Nothing to do for cleanup: won't delete any files

func (*AppSourceDir) Error

func (s *AppSourceDir) Error() error

Get R app source status

func (*AppSourceDir) Path

func (s *AppSourceDir) Path() string

Get R app directory path

Jump to