Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AppSource ¶
type AppSource interface {
Path() string // get the path to the folder containing R app scripts
Cleanup() error // cleanup if any when app is deleted
Error() error // get the error status if any
}
A generic application source interface
type AppSourceDir ¶
type AppSourceDir struct {
AppDir string
// contains filtered or unexported fields
}
A simple app source based on a local folder
func NewAppSourceDir ¶
func NewAppSourceDir(app models.App, conf config.Config) *AppSourceDir
func NewAppSourceSampleApp ¶
func NewAppSourceSampleApp(app models.App, conf config.Config) *AppSourceDir
func (*AppSourceDir) Cleanup ¶
func (s *AppSourceDir) Cleanup() error
Nothing to do for cleanup: won't delete any files
Click to show internal directories.
Click to hide internal directories.